@@ -180,10 +180,10 @@ struct psp {
     double
     get_g( pos_t seq, pos_t seq_pos ) = 0;
 
-    /// get the upper bound on the term: log(1-g)
+    /// get the bound on g
     virtual
     double
-    get_term_bound( top_down_it it ) = 0;
+    get_min_g( top_down_it it ) = 0;
 
     /// update after base-resolution priors have changed.
     virtual
@@ -195,7 +195,7 @@ struct psp {
 
 
 /**
- * Class that calculates model's priors from the base resolution priors in the data.
+ * Calculates model's priors from the base resolution priors in the data.
  *
  * Uses CRTP to store values in a derived class.
  */
@@ -205,7 +205,7 @@ template<
 >
 struct model_priors_calculator {
 
-    typedef data< Spec >              data_t;             ///< The data type.
+    typedef data< Spec >                        data_t;             ///< The data type.
 
     data_t &             _data;              ///< The data.
     size_t               W;                  ///< The width of the motif we are calculating the priors for.
@@ -224,7 +224,8 @@ struct model_priors_calculator {
     }
 
 protected:
-    /// Visit a node to calculate its weight
+
+    /// Visit a node to calculate its minimum and maximum
     double
     visit_node( top_down_it it ) {
         using namespace seqan;
@@ -234,7 +235,7 @@ protected:
         // used to identify this node.
         typename VertexDescriptor< index_t >::Type v = value( it );
 
-        // the smallest g in the sub-tree under this node
+        // the min g in the sub-tree under this node
         double min_g;
 
         // if we haven't reached depth W in tree, visit the node's children and update the maximum weight from them
@@ -243,10 +244,9 @@ protected:
             if( goDown( it ) ) {
                 min_g = visit_node( it );
                 while( goRight( it ) ) {
-                    double g;
-                    g = visit_node( it );
-                    if( g < min_g ) {
-                        min_g = g;
+                    const double child_min_g = visit_node( it );
+                    if( child_min_g < min_g ) {
+                        min_g = child_min_g;
                     }
                 }
             } else { // we had no children and we're not deep enough in the tree so the minimum g is 1.
@@ -278,10 +278,10 @@ protected:
             }
         }
 
-        // store bound on term if it is not 0.
+        // store minimum if it is not 0.
         if( min_g > 0. ) {
             // term will be infinite if min_g is 1.
-            static_cast< Derived * >( this )->store_term_bound( v, std::log( 1. - min_g ) );
+            static_cast< Derived * >( this )->store_min_g( v, min_g );
         }
 
         // return the minimum g for this sub-tree
@@ -309,8 +309,8 @@ struct dense_psp
     STEME_TYPEDEF_SEQAN_TYPES( Spec )
 
 protected:
-    vertex_g_vec                term_bound;         ///< The lower bound on log(1 + g/(1.-g)) for any occurrence under given node.
-    vec_pos_g_vecs              g;                  ///< The weights.
+    vertex_g_vec                min_g;         ///< Minimum g for any X_n under a suffix tree node.
+    vec_pos_g_vecs              g;             ///< The weights.
 
 public:
     /** Constructor. Descend the suffix tree to calculate the weights from the position-specific priors. */
@@ -323,8 +323,8 @@ public:
             g[ i ].resize( _data.get_sequence_length( i ) );
         }
 
-        // resize our map from vertices to maximum weights
-        seqan::resizeVertexMap( _data.index, term_bound );
+        // resize our map from vertices to minimum g
+        seqan::resizeVertexMap( _data.index, min_g );
 
         update();
     }
@@ -334,7 +334,7 @@ public:
     void
     update() {
         // fill with 0s
-        seqan::arrayFill( seqan::begin( term_bound ), seqan::end( term_bound ), 0. );
+        seqan::arrayFill( seqan::begin( min_g ), seqan::end( min_g ), 0. );
 
         // calculate the weights
         model_priors_calculator< dense_psp< Spec >, Spec >::calculate_weights();
@@ -350,8 +350,8 @@ public:
     /// Get a bound on the prior
     virtual
     double
-    get_term_bound( top_down_it it ) {
-        return getProperty( term_bound, value( it ) );
+    get_min_g( top_down_it it ) {
+        return getProperty( min_g, value( it ) );
     }
 
     /// Store g
@@ -361,12 +361,12 @@ public:
         this->g[ seq ][ seq_pos ] = g;
     }
 
-    /// Store the bound on the term
+    /// Store the bound on g
     inline
     void
-    store_term_bound( const typename seqan::VertexDescriptor< index_t >::Type & v, double bound ) {
-        // assign the maximum weights for this sub-tree to the node
-        assignProperty( term_bound, v, bound );
+    store_min_g( const typename seqan::VertexDescriptor< index_t >::Type & v, double g ) {
+        // assign the minimum prior for this sub-tree to the node
+        assignProperty( min_g, v, g );
     }
 };
 
@@ -391,8 +391,8 @@ struct sparse_psp
     STEME_TYPEDEF_SEQAN_TYPES( Spec )
 
 protected:
-    vertex_g_map         term_bound;         ///< The lower bound on log(1 + g/(1.-g)) for any occurrence under given node.
-    vec_pos_g_maps       g;                  ///< The weights.
+    vertex_g_map         min_g;         ///< Minimum g for all X_n under this node.
+    vec_pos_g_maps       g;             ///< The weights.
 
 public:
     /** Constructor. Descend the suffix tree to calculate the weights from the position-specific priors. */
@@ -416,12 +416,12 @@ public:
     /// Get a bound on the prior
     virtual
     double
-    get_term_bound( top_down_it it ) {
+    get_min_g( top_down_it it ) {
         using namespace seqan;
 
         // look for entry in our map
-        vertex_g_map::iterator i = term_bound.find( _getId( value( it ) ) );
-        return term_bound.end() == i ? 0. : i->second;
+        vertex_g_map::iterator i = min_g.find( _getId( value( it ) ) );
+        return min_g.end() == i ? 0. : i->second;
     }
 
     /// Return the weight at the given position.
@@ -446,11 +446,11 @@ public:
         }
     }
 
-    /// Store the bound on the term
+    /// Store the bound on g
     inline
     void
-    store_term_bound( const typename seqan::VertexDescriptor< index_t >::Type & v, double bound ) {
-        term_bound[ seqan::_getId( v ) ] = bound;
+    store_min_g( const typename seqan::VertexDescriptor< index_t >::Type & v, double bound ) {
+        min_g[ seqan::_getId( v ) ] = bound;
     }
 };
 
